@@ -36,7 +36,9 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
 #include "xf86Resources.h"
+#endif
 #include "xf86i2c.h"
 #include "xf86Crtc.h"
 #include "xf86cmap.h"
@@ -289,10 +291,10 @@ LXPreInit(ScrnInfoPtr pScrni, int flags)
 	return FALSE;
 
     pEnt = xf86GetEntityInfo(pScrni->entityList[0]);
-
+#ifndef XSERVER_LIBPCIACCESS
     if (pEnt->resources)
 	return FALSE;
-
+#endif
     if (flags & PROBE_DETECT) {
 	GeodeProbeDDC(pScrni, pEnt->index);
 	return TRUE;
@@ -311,7 +313,7 @@ LXPreInit(ScrnInfoPtr pScrni, int flags)
 	if (!xf86LoadSubModule(pScrni, "vgahw") || !vgaHWGetHWRec(pScrni))
 	    pGeode->useVGA = FALSE;
 
-	pGeode->vesa = xcalloc(sizeof(VESARec), 1);
+	pGeode->vesa = calloc(sizeof(VESARec), 1);
     }
 
     cim_rdmsr = LXReadMSR;
@@ -450,7 +452,7 @@ LXPreInit(ScrnInfoPtr pScrni, int flags)
 	    pGeode->panelMode = LXGetManualPanelMode(pmode);
 
 	if (pGeode->panelMode == NULL)
-	    pGeode->panelMode = LXGetLegacyPanelMode();
+	    pGeode->panelMode = LXGetLegacyPanelMode(pScrni);
 
 	if (pGeode->panelMode == NULL)
 	    pGeode->Output &= ~OUTPUT_PANEL;
@@ -570,13 +572,13 @@ LXPreInit(ScrnInfoPtr pScrni, int flags)
 	if (!xf86LoadSubModule(pScrni, "exa"))
 	    return FALSE;
     }
-
+#ifndef XSERVER_LIBPCIACCESS
     if (xf86RegisterResources(pGeode->pEnt->index, NULL, ResExclusive)) {
 	xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
 	    "Couldn't register the resources.\n");
 	return FALSE;
     }
-
+#endif
     return TRUE;
 }
 
@@ -696,7 +698,7 @@ LXCloseScreen(int scrnIndex, ScreenPtr pScrn)
 
     if (pGeode->pExa) {
 	exaDriverFini(pScrn);
-	xfree(pGeode->pExa);
+	free(pGeode->pExa);
 	pGeode->pExa = NULL;
     }
 
